@@ -17,9 +17,7 @@ class Distro(Module):
         usr = kw['usr']
         pub = kw['pub']
 
-        distro = target.distro
-
-        ok = distro.user(usr).deploy()
+        ok = target.user(usr)
         ok = ok and target.deploy('sudoers', user=usr)
         ok = ok and target.deploy('copy_id', **kw)
 
